@@ -80,6 +80,10 @@ class RecipeReader:
             values["quantity"] = Q_to_number(values["quantity"])
         values["unit"] = None
         values["unit"] = U_unify(values["unit"])
+        values["quantity"], values["unit"] = Q_U_unify(
+            values["quantity"], values["unit"]
+        )
+
         values["size"] = S_unify(values["size"])
 
         if values["ingredient"] != values["ingredient"]:
@@ -94,7 +98,7 @@ class RecipeReader:
             for c in ["quantity", "unit", "size", "color", "ingredient", "simple"]
         }
         filtered["simple"] = values["simple"]
-        return values["simple"]
+        return filtered
 
     def funnel(self, phrase):
         return ing_funnel[phrase] if phrase in ing_funnel else None
@@ -166,7 +170,7 @@ class RecipeReader:
         return out if len(out) > 0 else ["other"]
 
     def read(self, title, phrases, steps):
-        ingredients = [self.read_phrase(p) for p in phrases]
+        ingredients = [self.read_phrase(p)["simple"] for p in phrases]
         columns = sorted(list(set(list(ing_funnel.values()))))
         ingredients = [self.funnel(p) for p in ingredients if self.funnel(p)]
         categories = self.categorize(title, ingredients, steps)
